@@ -258,8 +258,7 @@ latexmk_emu = function(
           }
           if (!tlmgr_available() || !install_packages) return(warn())
           # install the possibly missing .bst package and rebuild bib
-          r = '.* open style file ([^ ]+).*'
-          pkgs = parse_packages(files = grep_sub(r, '\\1', x), quiet = !verbose)
+          pkgs = parse_packages(text = x, quiet = !verbose)
           if (length(pkgs) == 0 || identical(pkgs, pkgs_last)) return(warn())
           pkgs_last <<- pkgs
           tlmgr_install(pkgs); build_bib()
@@ -417,9 +416,11 @@ check_extra = function(file) {
 }
 
 check_babel = function(text) {
-  r = "^\\(babel).* language `([^']+)'.*$"
-  if (length(m <- grep_sub(r, '\\1', text)) == 0) return(FALSE)
-  tlmgr_install(paste0('hyphen-', tolower(m))) == 0
+  r = "^(\\(babel\\).* |Package babel Warning: No hyphenation patterns were preloaded for the )language [`']([^']+)'.*$"
+  if (length(m <- grep_sub(r, 'hyphen-\\2', text)) == 0) return(FALSE)
+  # (babel) the language `German (new orthography)' into the format
+  m = gsub('\\s.*', '', m)
+  tlmgr_install(tolower(m)) == 0
 }
 
 # Package glossaries Warning: No language module detected for `english'.
@@ -427,7 +428,7 @@ check_babel = function(text) {
 # (glossaries)                Please check on CTAN for a bundle called
 # (glossaries)                `glossaries-english' or similar.
 check_glossaries = function(text) {
-  r = "^\\(glossaries).* `([^']+)'.*$"
+  r = "^\\(glossaries).* [`']([^']+)'.*$"
   if (length(m <- grep_sub(r, '\\1', text)) == 0) return(FALSE)
   tlmgr_install(m) == 0
 }
@@ -435,7 +436,7 @@ check_glossaries = function(text) {
 # Package polyglossia Warning: No hyphenation patterns were loaded for `hungarian'
 # Package polyglossia Warning: No hyphenation patterns were loaded for British English
 check_polyglossia = function(text) {
-  r = "^Package polyglossia Warning: No hyphenation patterns were loaded for (`[^']+'|British English).*"
+  r = "^Package polyglossia Warning: No hyphenation patterns were loaded for ([`'][^']+'|British English).*"
   if (length(m <- grep_sub(r, '\\1', text)) == 0) return(FALSE)
   m[m == 'British English'] = 'english'
   m = gsub("[`']", '', m)
@@ -445,7 +446,7 @@ check_polyglossia = function(text) {
 # Package datetime2 Warning: Date-Time Language Module `english' not installed on
 # input line xxx.
 check_datetime2 = function(text) {
-  r = "^Package datetime2 Warning: Date-Time Language Module `([^']+)' not installed.*$"
+  r = "^Package datetime2 Warning: Date-Time Language Module [`']([^']+)' not installed.*$"
   if (length(m <- grep_sub(r, '\\1', text)) == 0) return(FALSE)
   tlmgr_install(paste0('datetime2-', m)) == 0
 }
@@ -574,7 +575,7 @@ regex_errors = function() {
     ),
     epstopdf = c(
       # possible errors when epstopdf is missing
-      ".* File `(.+eps-converted-to.pdf)'.*",
+      ".* File [`'](.+eps-converted-to.pdf)'.*",
       ".*xdvipdfmx:fatal: pdf_ref_obj.*"
     ),
     colorprofiles.sty = c(
@@ -587,14 +588,15 @@ regex_errors = function() {
     style = c(
       # missing .sty or commands
       ".* Loading '([^']+)' aborted!",
-      ".*! LaTeX Error: File `([^']+)' not found.*",
+      ".*! LaTeX Error: File [`']([^']+)' not found.*",
       ".* file ['`]?([^' ]+)'? not found.*",
       '.*the language definition file ([^ ]+) .*',
       '.* \\(file ([^)]+)\\): cannot open .*',
-      ".*file `([^']+)' .*is missing.*",
-      ".*! CTeX fontset `([^']+)' is unavailable.*",
+      '.* open style file ([^ ]+).*',
+      ".*file [`']([^']+)' .*is missing.*",
+      ".*! CTeX fontset [`']([^']+)' is unavailable.*",
       ".*: ([^:]+): command not found.*",
-      ".*! I can't find file `([^']+)'.*"
+      ".*! I can't find file [`']([^']+)'.*"
     )
   )
 }
